pub struct CommitSemanticallyVerifiedBlockRequest(pub SemanticallyVerifiedBlock);Expand description
Performs contextual validation of the given semantically verified block, committing it to the state if successful.
See the crate documentation and Request::CommitSemanticallyVerifiedBlock for details.
Tuple Fields
0: SemanticallyVerifiedBlockTrait Implementations
Sourceimpl MappedRequest for CommitSemanticallyVerifiedBlockRequest
impl MappedRequest for CommitSemanticallyVerifiedBlockRequest
Sourcetype MappedResponse = Hash
type MappedResponse = Hash
Expected response type for this state request.
Sourcetype Error = CommitSemanticallyVerifiedError
type Error = CommitSemanticallyVerifiedError
Expected error type for this state request.
Sourcefn map_request(self) -> Request
fn map_request(self) -> Request
Maps the request type to a
Request.Sourcefn map_response(response: Response) -> Self::MappedResponse
fn map_response(response: Response) -> Self::MappedResponse
Maps the expected
Response variant for this request to the mapped response type.Sourceasync fn mapped_oneshot<State>(
self,
state: &mut State,
) -> Result<Self::MappedResponse, LayeredStateError<Self::Error>>
async fn mapped_oneshot<State>( self, state: &mut State, ) -> Result<Self::MappedResponse, LayeredStateError<Self::Error>>